httpcore: Minimal low-level HTTP client
=======================================

Description
-----------

Minimal low-level HTTP client

License
-------

Upstream Contact
----------------

https://pypi.org/project/httpcore/

